summaryrefslogtreecommitdiff
path: root/src/SMAPI.Web/ViewModels
diff options
context:
space:
mode:
Diffstat (limited to 'src/SMAPI.Web/ViewModels')
-rw-r--r--src/SMAPI.Web/ViewModels/LogParserModel.cs9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/SMAPI.Web/ViewModels/LogParserModel.cs b/src/SMAPI.Web/ViewModels/LogParserModel.cs
index f4c5214b..b06b5b2d 100644
--- a/src/SMAPI.Web/ViewModels/LogParserModel.cs
+++ b/src/SMAPI.Web/ViewModels/LogParserModel.cs
@@ -1,3 +1,4 @@
+using System;
using System.Collections.Generic;
using System.Linq;
using System.Text.RegularExpressions;
@@ -34,12 +35,18 @@ namespace StardewModdingAPI.Web.ViewModels
/// <summary>Whether to show the raw unparsed log.</summary>
public bool ShowRaw { get; set; }
- /// <summary>An error which occurred while uploading the log to Pastebin.</summary>
+ /// <summary>A non-blocking warning while uploading the log.</summary>
+ public string UploadWarning { get; set; }
+
+ /// <summary>An error which occurred while uploading the log.</summary>
public string UploadError { get; set; }
/// <summary>An error which occurred while parsing the log file.</summary>
public string ParseError => this.ParsedLog?.Error;
+ /// <summary>When the uploaded file will no longer be available.</summary>
+ public DateTime? Expiry { get; set; }
+
/*********
** Public methods